@@ -7,8 +7,14 @@ theme = Theme(
         "deleted": "underline bright_red",
         "inserted": "bright_green",
         "language": "light_goldenrod2 bold",
+        "progress": "light_sky_blue3",
         "quiz": "medium_purple1",
+        "answer": "grey69",
         "secondary": "grey69",
+        "colloquial": "grey69",
+        "example": "grey69",
+        "meaning": "grey69",
+        "note": "grey69",
         "retention": "grey50",
     }
 )
